@@ -68,8 +68,9 @@ from botocore.hooks import (
 from botocore.loaders import create_loader
 from botocore.model import ServiceModel
 from botocore.parsers import ResponseParserFactory
+from botocore.plugin import get_botocore_plugins, load_client_plugins
 from botocore.regions import EndpointResolver
-from botocore.useragent import UserAgentString
+from botocore.useragent import UserAgentString, register_feature_id
 from botocore.utils import (
     EVENT_ALIASES,
     IMDSRegionProvider,
@@ -978,10 +979,13 @@ class Session:
                 aws_session_token, aws_account_id
             ):
                 logger.debug(
-                    f"Ignoring the following credential-related values which were set without "
-                    f"an access key id and secret key on the session or client: {ignored_credentials}"
+                    "Ignoring the following credential-related values which were set without "
+                    "an access key id and secret key on the session or client: %s",
+                    ignored_credentials,
                 )
             credentials = self.get_credentials()
+        if getattr(credentials, 'method', None) == 'explicit':
+            register_feature_id('CREDENTIALS_CODE')
         auth_token = self.get_auth_token()
         endpoint_resolver = self._get_internal_component('endpoint_resolver')
         exceptions_factory = self._get_internal_component('exceptions_factory')
@@ -1039,6 +1043,7 @@ class Session:
         monitor = self._get_internal_component('monitor')
         if monitor is not None:
             monitor.register(client.meta.events)
+        self._register_client_plugins(client)
         return client
 
     def _resolve_region_name(self, region_name, config):
@@ -1164,6 +1169,24 @@ class Session:
             credential_inputs.append('aws_account_id')
         return ', '.join(credential_inputs) if credential_inputs else None
 
+    def _register_client_plugins(self, client):
+        plugins_list = get_botocore_plugins()
+        if plugins_list == "DISABLED" or not plugins_list:
+            return
+
+        client_plugins = {}
+        for plugin in plugins_list.split(','):
+            try:
+                name, module = [part.strip() for part in plugin.split('=')]
+                client_plugins[name] = module
+            except ValueError:
+                logger.warning(
+                    "Invalid plugin format: %s. Expected 'name=module'", plugin
+                )
+
+        if client_plugins:
+            load_client_plugins(client, client_plugins)
+
 
 class ComponentLocator:
     """Service locator for session components."""
